Crate kcr_apacheweb_arsenal_dev

Crate kcr_apacheweb_arsenal_dev 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the apacheweb.arsenal.dev group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

apacheweb.arsenal.dev/v1alpha1

  • Apacheweb

Modules

v1alpha1